Learn R Programming

partsm (version 1.0-1)

Fpari.piar.test: Test for a Parameter Restriction in a PAR Model.

Description

This function performs a test for a parameter restriction in a PAR model. Two restrictions can be considered and entail that the process contain either the unit root 1 or the seasonal unit root -1. In this version PAR models up to order 2 can be considered.

Usage

Fpari.piar.test (wts, detcomp, p, type)

Arguments

wts
a univariate time series object.
detcomp
a vector indicating the deterministic components included in the auxiliar regression. See the corresponding item in fit.ar.par.
p
the order of the initial AR or PAR model. In this version PAR models up to order 2 with seasonal intercepts are considered.
type
a character string indicating which restriction should be tested. "PARI1" inidicates that the unit root is tested whereas "PARI-1" test for the unit root -1.

Value

  • An object of class Ftest.partsm-class containing the $F$-test statistic, the freedom degrees an the corresponding $p$-value.

Details

On the basis of the following PAR model (in this version PAR models up to order 2 are considered and seasonal intercepts are included default),

$$y_t = \mu_s + \alpha_s y_{t-1} + \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t,$$

for $s=1,...,S$, two different hypotheses can be tested:

  • $H0: \alpha_s = 1, for s=1,...S-1$,
  • $H0: \alpha_s = -1, for s=1,...S-1$.

For S=4, if the hypothesis $\alpha_1*\alpha_2*\alpha_3*\alpha_4=1$ cannot be rejected (see LRurpar.test), the null hypotheses above entails that either $\alpha_4=1$ or $\alpha_4=-1$.

When the first H0 is not rejected, the PAR model contains the unit root 1, and the periodic difference filter is just the first order difference, $(1-L)$, where $L$ is the lag operator.

When the second H0 is not rejected, the PAR model contains the unit root -1, and the periodic difference filter is simplified as $(1+L)$.

In both null hypotheses it is said that the data behave as a PAR model for an integrated series, known as PARI. If those null hypotheses are rejected, the corresponding model is called a periodically integrated autoregressive model, PIAR.

The asymptotic distribution of the F-statistic is $F(S-1, n-k)$, where $n$ is the number of observations and $k$ the number of regressors.

In this version PAR models up to order 2 can be considered.

See Also

Ftest.partsm-class, and LRurpar.test.

Examples

Run this code
## Test for the unit root 1 in a PAR(2) with seasonal intercepts for
    ## the logarithms of the Real GNP in Germany.
    data("gergnp")
    lgergnp <- log(gergnp, base=exp(1))
    detcomp <- list(regular=c(0,0,0), seasonal=c(1,0), regvar=0)
    out <- Fpari.piar.test(wts=lgergnp, detcomp=detcomp, p=2, type="PARI1")

Run the code above in your browser using DataLab