Learn R Programming

partsm (version 1.0-1)

Ftest.partsm: Ftest.partsm Class

Description

This class contains the information provided by the $F$-tests available in the package 'partsm'.

Arguments

References

P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).

See Also

Fnextp.test, Fpar.test, Fsh.test, and Fpari.piar.test.