This class contains the information provided by LRurpar.test.
test.label:Object of class "character": A label to identify the test.
test.name:Object of class "character": A one-line descriptio of the test.
p:Object of class "numeric": The lag order parameter of the model.
LR:Object of class "numeric": The LR statistic.
LRtau:Object of class "numeric": The one side test statistic.
h0nls:Object of class "matrix": The estimated coefficients of the non-linear PIAR
model.
halm:Object of class "lm": The estimated PAR model for the alternative
hypotheses.
show:Shows the LR statistics and a one-side test constructed as \(sign(g(\hat{\alpha}) - 1) * LR^{1/2}\), where \(g(\hat{\alpha})\) is the product of the periodic differencing filter parameters estimated under the alternative.
summary:Displays the same output as show but a summary of the null and the
alternative hypotheses is also displayed.
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).