Rdocumentation
powered by
Learn R Programming
partsm (version 1.0-1)
MVPAR-class: MVPAR Class
Description
This class contains the matrices for the multivariate representation of an object of class
fit.partsm-class
.
Arguments
References
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
See Also
PAR.MVrepr-methods
, and
fit.partsm-class
.