This class contains information on the autoregressive or periodic autoregressive parameters estimated by
fit.ar.par.
type:Object of class "character": The type of the fitted model, an autoregressive
model, "AR", or a periodic autoregressive model, "PAR".
p:Object of class "numeric": The lag order parameter of the model.
lm.ar:Object of class "ANY": The summary of a fitted AR model. When an AR type
model is selected, it is of class "lm", otherwise the slot is empty.
lm.par:Object of class "ANY": The summary of a fitted PAR model. When a PAR type
model is selected, it is of class "lm", otherwise the slot is empty.
ar.coeffs:Object of class "ANY": The autoregressive parameters estimates. When a
PAR type model is selected, it is of class "matrix", otherwise the slot is empty.
par.coeffs:Object of class "ANY": The periodic autoregressive parameters
estimates. When a PAR type model is selected, it is of class "matrix", otherwise the slot is
empty.
show:This method reports the autoregressive or periodic autoregressive estimates, depending whether the model is an AR model or a PAR model.
summary:In addition to the information reported by show, a summary of the fitted
model is also added.
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).