This class contains information on the periodic autoregressive parameters estimated by
fit.piar.
p:Object of class "numeric": The order of the PIAR model.
nls.parameters:Object of class "matrix": Estimated coefficicents of the
non-linear PIAR model.
nls.res:Object of class "numeric": Residuals of the non-linear PIAR model.
par.coeffs:Object of class "matrix": Periodic autoregressive parameters
estimates.
pdiff.data:Object of class "ts": Periodically differenced data.
show:Reports the periodic autoregressive coefficients estimates.
summary:Like show, the periodically differenced data are also displayed.
plot:Plot the the periodically differenced data, as well as the seasonal paths of the transformed data.
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).