This class contains the information provided by predictpiar.
wts:Object of class "wts": The observed time series.
hpred:Object of class "numeric": The number of forecasts.
p:Object of class "numeric": The lag order parameter of the PIAR model.
fcast:Object of class "ts": The out-of-sample forecasts.
fse:Object of class "ts": The forecast standard errors.
ucb:Object of class "ts": The upper 95 per cent confidence bound.
lcb:Object of class "ts": The lower 95 per cent confidence bound.
show:Shows out-of-sample forecasts and the corresponding standard errors, as well as the 95 per cent confidence intervals.
Javier Lopez-de-Lacalle javlacalle@yahoo.es.
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
predictpiar.