On the basis of the following PAR model (in this version PAR models up to order 2 are considered and
seasonal intercepts are included default), $$y_t = \mu_s + \alpha_s y_{t-1} + \beta_s (y_{t-1} - \alpha_{s-1} y_{t-2}) + \epsilon_t,$$
for $s=1,...,S$, two different hypotheses can be tested:
- $H0: \alpha_s = 1, for s=1,...S-1$,
- $H0: \alpha_s = -1, for s=1,...S-1$.
For S=4, if the hypothesis $\alpha_1*\alpha_2*\alpha_3*\alpha_4=1$ cannot be rejected (see
LRurpar.test), the null hypotheses above entails that either $\alpha_4=1$ or $\alpha_4=-1$.
When the first H0 is not rejected, the PAR model contains the unit root 1, and the periodic difference
filter is just the first order difference, $(1-L)$, where $L$ is the lag operator.
When the second H0 is not rejected, the PAR model contains the unit root -1, and the periodic difference
filter is simplified as $(1+L)$.
In both null hypotheses it is said that the data behave as a PAR model for an integrated series, known as
PARI. If those null hypotheses are rejected, the corresponding model is called a periodically integrated
autoregressive model, PIAR.
The asymptotic distribution of the F-statistic is $F(S-1, n-k)$, where $n$ is the number of
observations and $k$ the number of regressors.
In this version PAR models up to order 2 can be considered.