This class contains the information provided by the \(F\)-tests available in the package
'partsm'.
test.label:Object of class "character": A label to identify the test that the
information is related to.
test.name:Object of class "character": A one-line description of the test.
p:Object of class "numeric": The order of the AR or PAR model.
Fstat:Object of class "numeric": The \(F\)-statistic.
df:Object of class "numeric": The freedom degrees.
pval:Object of class "numeric": The \(p\)-value.
pvl:Object of class "character": A symbol indicating the significance of the
\(F\)-statistic according to usual codes, i.e. Signif. codes: 0 '***' 0.001 '**' 0.01 '*'
0.05 '.' 0.1 ' ' 1.
h0md:Object of class "lm": The summary of the model fitted for the null
hypothesis.
hamd:Object of class "ANY": The summary of the model fitted for the
alternative hypothesis.
show:This method reports the \(F\)-test statistic, the null and the alternative hypotheses entailed in the procedure, as well as the freedom degrees, the \(p\)-value and the codified \(p\)-value.
summary:In addition to the information reported by show, a summary of the fitted
models for the null and the alternative hypotheses is also added.
P.H. Franses: Periodicity and Stochastic Trends in Economic Time Series (Oxford University Press, 1996).
Fnextp.test, Fpar.test, Fsh.test, and
Fpari.piar.test.